Document: cpp-@BV@
Title: The GNU C preprocessor
Author: Various
Abstract: The C preprocessor is a "macro processor" that is used automatically
 by the C compiler to transform your program before actual compilation.
 It is called a macro processor because it allows you to define "macros",
 which are brief abbreviations for longer constructs.
Section: Programming

Format: html
Index: /usr/share/doc/gcc-@BV@-base/cpp.html
Files: /usr/share/doc/gcc-@BV@-base/cpp.html

Format: info
Index: /usr/share/info/cpp-@BV@.info.gz
Files: /usr/share/info/cpp-@BV@*
